@@ -18,6 +18,15 @@ class VariableList2D:
         initial = np.array([xi, yi])
         self.vals: np.ndarray[np.ndarray] = np.array([initial])
 
+    @classmethod
+    def from_array(cls, name, arr: np.ndarray):
+        return cls(name, arr[0], arr[1])
+
+    @classmethod
+    def empty(cls, name):
+        inst = cls(name)
+        inst.vals = np.array([])
+
     def append(self, x, y):
         arr = np.array([x, y])
         self.add(arr)
@@ -62,10 +71,6 @@ class VariableList2D:
     def __delitem__(self, key: int):
         del self.vals[key]
 
-    @classmethod
-    def from_array(cls, name, arr: np.ndarray):
-        return cls(name, arr[0], arr[1])
-
     @property
     def value(self):
         return self.vals[-1]
@@ -91,7 +96,7 @@ class VariableList2D:
         return np.linalg.norm(self.value)
 
 
-def scatter_2d(x_list, y_list):
+def scatter_2d(x_list, y_list, do_x=False):
     if isinstance(x_list, VariableList):
         x_name = x_list.name
         x_vals = x_list
@@ -103,8 +108,8 @@ def scatter_2d(x_list, y_list):
         y_name = y_list.name
         y_vals = y_vals
     elif isinstance(y_list, VariableList2D):
-        y_name = y_list.y_name
-        y_vals = y_list.y_values
+        y_name = y_list.y_name if not do_x else y_list.x_name
+        y_vals = y_list.y_values if not do_x else y_list.x_values
 
     plt.scatter(x_vals, y_vals)
     plt.xlabel(x_name)
